emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 3ca5453 1/5: * lisp/leim/quail/georgian.el: Add geo


From: Eli Zaretskii
Subject: [Emacs-diffs] master 3ca5453 1/5: * lisp/leim/quail/georgian.el: Add georgian-qwerty input method
Date: Sun, 14 Jul 2019 02:56:03 -0400 (EDT)

branch: master
commit 3ca545309375ed5145bc76350facc5a8c4453740
Author: Nick Drozd <address@hidden>
Commit: Eli Zaretskii <address@hidden>

    * lisp/leim/quail/georgian.el: Add georgian-qwerty input method
---
 lisp/leim/quail/georgian.el | 57 +++++++++++++++++++++++++++++++++++++++++++--
 1 file changed, 55 insertions(+), 2 deletions(-)

diff --git a/lisp/leim/quail/georgian.el b/lisp/leim/quail/georgian.el
index 61003b8..7ca3f79 100644
--- a/lisp/leim/quail/georgian.el
+++ b/lisp/leim/quail/georgian.el
@@ -22,8 +22,12 @@
 
 ;;; Commentary:
 
 ;; Georgian input following the Yudit map from Mark Leisher
 ;; <address@hidden>.
 
 ;;; Code:
 
@@ -80,4 +84,53 @@
  ("e1" ?) ;; Letter not in Unicode (private use code).
  )
 
+(quail-define-package
+ "georgian-qwerty" "Georgian" "ქ" t
+ "Georgian input based on QWERTY keyboard."
+ nil t nil nil t nil nil nil nil nil t)
+
+(quail-define-rules
+ ("a" ?ა)
+ ("b" ?ბ)
+ ("g" ?გ)
+ ("d" ?დ)
+ ("e" ?ე)
+ ("v" ?ვ)
+ ("z" ?ზ)
+ ("T" ?თ)
+ ("i" ?ი)
+ ("k" ?კ)
+ ("l" ?ლ)
+ ("m" ?მ)
+ ("n" ?ნ)
+ ("o" ?ო)
+ ("p" ?პ)
+ ("J" ?ჟ)
+ ("r" ?რ)
+ ("s" ?ს)
+ ("t" ?ტ)
+ ("u" ?უ)
+ ("f" ?ფ)
+ ("q" ?ქ)
+ ("R" ?ღ)
+ ("y" ?ყ)
+ ("S" ?შ)
+ ("C" ?ჩ)
+ ("c" ?ც)
+ ("Z" ?ძ)
+ ("w" ?წ)
+ ("W" ?ჭ)
+ ("x" ?ხ)
+ ("j" ?ჯ)
+ ("h" ?ჰ)
+ ("X" ?ჴ)
+ ("H" ?ჱ)
+ ("K" ?ჵ)
+ ("I" ?ჲ)
+ ("V" ?ჳ)
+ ("F" ?ჶ)
+ ("Y" ?ჸ)
+ ("G" ?ჷ)
+ )
+
 ;;; georgian.el ends here
@@ -22,8 +22,12 @@
 ;;; Commentary:
 
-;; Georgian input following the Yudit map from Mark Leisher
-;; <address@hidden>.
+;; This file defines the following Georgian keyboards:
+;;
+;; - Georgian input following the Yudit map from Mark Leisher
+;;   <address@hidden>.
+;;
+;; - QWERTY-based Georgian.
 
 ;;; Code:



reply via email to

[Prev in Thread] Current Thread [Next in Thread]